# Security Policy

## Reporting a Vulnerability

If you discover a security vulnerability, please report it responsibly by emailing **support@datalegion.ai**.

Please do **not** open a public GitHub issue for security vulnerabilities.

We will acknowledge your report within 48 hours and provide a detailed response within 5 business days, including next steps for handling the vulnerability.
